// app/students/[id]/StudentDetailsClient.tsx (CLIENT COMPONENT)
"use client";

import { useEffect, useRef, useState } from "react";
import { useRouter } from "next/navigation";
import { useAuth } from "@/lib/hooks/useAuth";
import { useStudents } from "@/lib/hooks/useStudents";
import DashboardLayout from "@/components/layout/DashboardLayout";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { ArrowLeft, Building, Calendar, CalendarCheck, Camera, GraduationCap, Home, HomeIcon, Mail, Phone, School, School2, User, X } from "lucide-react";
import { Student } from "@/lib/types";
import { Badge } from "@/components/ui/badge";
import { toast } from "sonner";

export default function StudentDetailsPage({ params }: { params: { id: string } }) {
  const router = useRouter();
  const { user } = useAuth();
  const { students, updateStudent } = useStudents();
  const [student, setStudent] = useState<Student | null>(null);
  const [isUploading, setIsUploading] = useState(false);
  const fileInputRef = useRef<HTMLInputElement>(null);
  const [isImageModalOpen, setIsImageModalOpen] = useState(false);

   useEffect(() => {
    if (params.id) {
      const foundStudent = students.find(s => s.id === params.id);
      setStudent(foundStudent || null);
    }
  }, [params.id, students]);

    const handlePhotoUpload = async (e: React.ChangeEvent<HTMLInputElement>) => {
    const file = e.target.files?.[0];
    if (!file || !student) return;

    try {
      setIsUploading(true);
      
      // Create FormData and append file
      const formData = new FormData();
      formData.append('file', file);
      
      // Upload file to server
      const response = await fetch('/api/upload', {
        method: 'POST',
        body: formData,
      });

      if (!response.ok) throw new Error('Failed to upload image');

      const { url } = await response.json();
      
      // Update student profile with new photo URL
      await updateStudent(student.id, { profilePicture: url });
      setStudent({ ...student, profilePicture: url });
      toast.success("Profile picture updated successfully", {
        style: {
          background: '#4BB543', // Green color for success
          color: '#ffffff',
          border: '1px solid #3FAF3A',
        },
      });
    } catch (error) {
      console.error("Error uploading photo:", error);
      toast.error("Failed to upload profile picture", {
        style: {
          background: '#FF3333', // Red color for error
          color: '#ffffff',
          border: '1px solid #E60000',
        },
      });
    } finally {
      setIsUploading(false);
    }
  };

  if (!student) {
    return (
      <DashboardLayout>
        <div className="flex items-center justify-center h-[calc(100vh-4rem)]">
          <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
        </div>
      </DashboardLayout>
    );
  }

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="flex items-center gap-4">
          <Button
            variant="ghost"
            size="sm"
            onClick={() => router.back()}
          >
            <ArrowLeft className="h-4 w-4 mr-2" />
            Back
          </Button>
          <div>
            <h1 className="text-3xl font-bold tracking-tight">Student Details</h1>
            <p className="text-muted-foreground">
              View detailed information about {student.firstName} {student.lastName}
            </p>
          </div>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
          <Card>
            <CardHeader>
              <CardTitle>Personal Information</CardTitle>
            </CardHeader>
            <CardContent className="space-y-4">
              <div className="flex items-center gap-4">
                <div className="relative">
        {student.profilePicture ? (
          <>
            <img
              src={student.profilePicture}
              alt={`${student.firstName} ${student.lastName}`}
              className="h-24 w-24 rounded-full object-cover border-2 border-border cursor-pointer hover:opacity-80 transition-opacity"
              onClick={() => setIsImageModalOpen(true)}
            />
            
            {/* Modal for full-size image */}
            {isImageModalOpen && (
              <div className="fixed inset-0 bg-black/80 z-50 flex items-center justify-center p-4">
                <div className="relative bg-background rounded-lg max-w-4xl max-h-[90vh] overflow-auto">
                  <img
                    src={student.profilePicture}
                    alt={`${student.firstName} ${student.lastName}`}
                    className="w-full h-auto max-h-[80vh] object-contain"
                  />
                  <button
                    onClick={() => setIsImageModalOpen(false)}
                    className="absolute top-4 right-4 p-2 rounded-full bg-foreground/10 hover:bg-foreground/20 transition-colors"
                  >
                    <X className="h-6 w-6 text-white" />
                  </button>
                </div>
              </div>
            )}
          </>
        ) : (
          <div className="h-24 w-24 rounded-full bg-primary/10 flex items-center justify-center border-2 border-border">
            <User className="h-12 w-12 text-primary" />
          </div>
        )}

        {(user?.role === "admin" || user?.role === "teacher") && (
          <Button
            size="sm"
            variant="secondary"
            className="absolute -bottom-2 -right-2 h-8 w-8 rounded-full p-0"
            onClick={() => fileInputRef.current?.click()}
            disabled={isUploading}
          >
            <Camera className="h-4 w-4" />
          </Button>
        )}

        <input
          type="file"
          ref={fileInputRef}
          className="hidden"
          accept="image/*"
          onChange={handlePhotoUpload}
        />
          </div>

      <div>
        <h2 className="text-2xl font-bold">
          {student.firstName} {student.lastName}
        </h2>
        {/* <p className="text-muted-foreground">Student ID: {student.id}</p> */}
        {isUploading && (   
          <p className="text-sm text-muted-foreground">Uploading...</p>
        )}
      </div>
    </div>
              <div className="space-y-2">
                <div className="flex items-center gap-2">
                  <Phone className="h-4 w-4 text-muted-foreground" />
                  <span>{student.phone || "No phone"}</span>
                </div>
                <div className="flex items-center gap-2">
                  <CalendarCheck className="h-4 w-4 text-muted-foreground" />
                  <span>
                  {new Date(student.dateOfBirth).toLocaleDateString('en-GB', {
                    day: '2-digit',
                    month: 'long',
                    year: 'numeric'
                  })}
                  </span>
                </div>
                <div className="flex items-center gap-2">
                  <HomeIcon className="h-4 w-4 text-muted-foreground" />
                  <p>{student.address}</p>
                </div>
                <div className="flex items-center gap-2">
                  <School className="h-4 w-4 text-muted-foreground" />
                  <p>{student.academicSchool || "---"}</p>  
                </div>
              </div>
            </CardContent>
          </Card>

          <Card>
            <CardHeader>
              <CardTitle>Academic Information</CardTitle>
            </CardHeader>
            <CardContent className="space-y-4">
              <div className="grid grid-cols-2 gap-4">
                <div>
                  <p className="text-sm text-muted-foreground">Enrollment Date</p>
                  <div className="flex items-center gap-2">
                  <CalendarCheck className="h-4 w-4 text-muted-foreground" />
                    <p className="font-medium">
                    {new Date(student.enrollmentDate).toLocaleDateString('en-GB', {
                      day: '2-digit',
                      month: 'long',
                      year: 'numeric'
                    })}
                    </p>
                  </div>
                </div>
                <div>
                  <p className="text-sm text-muted-foreground">Status</p>
                  <span
                    className={`inline-flex items-center rounded-full px-2.5 py-0.5 text-xs font-medium ${
                      student.status === "active"
                        ? "bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-300"
                        : student.status === "inactive"
                        ? "bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-300"
                        : "bg-blue-100 text-blue-800 dark:bg-blue-900 dark:text-blue-300"
                    }`}
                  >
                    {student.status}
                  </span>
                </div>
              </div>

              <div className="grid grid-cols-2 gap-4">
                <div>
                  <p className="text-sm text-muted-foreground mb-1">Parent Information</p>
                  <div className="space-y-2">
                    <div className="flex items-center gap-2">
                      <User className="h-4 w-4 text-muted-foreground" />
                      <p className="font-medium">{student.parentName || "---"}</p>
                    </div>
                    <div className="flex items-center gap-2">
                      <Mail className="h-4 w-4 text-muted-foreground" />
                      <p>{student.parentEmail || "---"}</p>
                    </div>
                    <div className="flex items-center gap-2">
                      <Phone className="h-4 w-4 text-muted-foreground" />
                      <p>{student.parentContact || "---"}</p>
                    </div>
                  </div>
                </div>

                <div>
                  <p className="text-sm text-muted-foreground mb-1">Next of Kin Information</p>
                  <div className="space-y-2">
                    <div className="flex items-center gap-2">
                      <User className="h-4 w-4 text-muted-foreground" />
                      <p className="font-medium">{student.kin || "---"}</p>
                    </div>
                    <div className="flex items-center gap-2">
                      <Phone className="h-4 w-4 text-muted-foreground" />
                      <p>{student.kinContact || "---"}</p>
                    </div>
                  </div>
                </div>  
              </div>
              <div>
                <div className="flex items-center gap-1 flex-wrap">
                      <span>Classes:</span>
                      {student.classes?.length ? (
                        student.classes.map(cls => {
                          const displayName = cls.level 
                            ? `${cls.name} (${cls.level})` 
                            : cls.name;
                          return (
                            <Badge key={cls.id} variant="outline" className="text-sm">
                              {displayName}
                            </Badge>
                          );
                        })
                      ) : (
                        <Badge variant="outline" className="text-sm">
                          Unassigned
                        </Badge>
                      )}
                    </div>
              </div>
            </CardContent>
          </Card>
        </div>

        <Card>
          <CardHeader>
            <CardTitle>Recent Activity</CardTitle>
          </CardHeader>
          <CardContent>
            <div className="space-y-4">
              {/* This would be populated with actual activity data */}
              <p className="text-muted-foreground">No recent activity to display</p>
            </div>
          </CardContent>
        </Card>
      </div>
    </DashboardLayout>
  );
}

function setIsUploading(arg0: boolean) {
  throw new Error("Function not implemented.");
}

